### Tell us about a problem or need in society related to the COVID-19 outbreak, what you already know about it, and what you would need to know to solve it. While not required, many strong applications will tie the applicant's experience in technology to the problem described here. (Enter up to 250 words.) 


### Propose a concrete project you would like to execute related to the problem you described above. Describe in detail the proposed solution, including why existing solutions are insufficient to solve the problem. Also include operational details such as what you intend to build (your outputs) and how you intend to communicate what you've built (your advocacy plan).  (Enter up to 500 words.)

### Please describe the timeline in which you plan to execute your project, including key milestones. Projects must be able to be completed in 3 months. (Enter up to 150 words.)

###The team lead submitting the grant must have existing substantive civic technology and/or technology policy experience. Illustrative examples of such qualifications include participation in the US Digital Service, Presidential Innovation Fellows, Aspen Tech Policy Hub, or TechCongress; Illustrative examples of relevant qualifications include past participation in the US Digital Service, Presidential Innovation Fellows, Aspen Tech Policy Hub, or TechCongress; experience in a government agency working on tech policy; or experience working in public policy at a tech company.nIn 1-2 sentences, please briefly describe the team lead's professional experience and/or training working with technology. (Please note you will have the chance to attach a resume below.) * (Enter up to 75 words)

### In 1-2 sentences, please briefly describe the team lead's past experience engaging in the policy process. 

